==> huaweicloudsdkiec-3.1.137-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/attach_vip_bandwidth_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AttachVipBandwidthRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_id': 'str'
    }

    attribute_map = {
        'bandwidth_id': 'bandwidth_id'
    }

    def __init__(self, bandwidth_id=None):
        """AttachVipBandwidthRequestBody

        The model defined in huaweicloud sdk

        :param bandwidth_id: 带宽ID。
        :type bandwidth_id: str
        """
        
        

        self._bandwidth_id = None
        self.discriminator = None

        self.bandwidth_id = bandwidth_id

    @property
    def bandwidth_id(self):
        """Gets the bandwidth_id of this AttachVipBandwidthRequestBody.

        带宽ID。

        :return: The bandwidth_id of this AttachVipBandwidthRequestBody.
        :rtype: str
        """
        return self._bandwidth_id

    @bandwidth_id.setter
    def bandwidth_id(self, bandwidth_id):
        """Sets the bandwidth_id of this AttachVipBandwidthRequestBody.

        带宽ID。

        :param bandwidth_id: The bandwidth_id of this AttachVipBandwidthRequestBody.
        :type bandwidth_id: str
        """
        self._bandwidth_id = bandwidth_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachVipBandwidthRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiec-3.1.145-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/attach_vip_bandwidth_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AttachVipBandwidthRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_id': 'str'
    }

    attribute_map = {
        'bandwidth_id': 'bandwidth_id'
    }

    def __init__(self, bandwidth_id=None):
        r"""AttachVipBandwidthRequestBody

        The model defined in huaweicloud sdk

        :param bandwidth_id: 带宽ID。
        :type bandwidth_id: str
        """
        
        

        self._bandwidth_id = None
        self.discriminator = None

        self.bandwidth_id = bandwidth_id

    @property
    def bandwidth_id(self):
        r"""Gets the bandwidth_id of this AttachVipBandwidthRequestBody.

        带宽ID。

        :return: The bandwidth_id of this AttachVipBandwidthRequestBody.
        :rtype: str
        """
        return self._bandwidth_id

    @bandwidth_id.setter
    def bandwidth_id(self, bandwidth_id):
        r"""Sets the bandwidth_id of this AttachVipBandwidthRequestBody.

        带宽ID。

        :param bandwidth_id: The bandwidth_id of this AttachVipBandwidthRequestBody.
        :type bandwidth_id: str
        """
        self._bandwidth_id = bandwidth_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachVipBandwidthRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
